@@ -32,16 +32,17 @@ class Test(unittest.TestCase):
 
     def test_import(self):
         from zope.interface.verify import verifyObject
+
         from zope.security import management
-        from zope.security.interfaces import ISecurityManagement
         from zope.security.interfaces import IInteractionManagement
+        from zope.security.interfaces import ISecurityManagement
 
         verifyObject(ISecurityManagement, management)
         verifyObject(IInteractionManagement, management)
 
     def test_securityPolicy(self):
-        from zope.security.management import setSecurityPolicy
         from zope.security.management import getSecurityPolicy
+        from zope.security.management import setSecurityPolicy
         from zope.security.simplepolicies import PermissiveSecurityPolicy
 
         policy = PermissiveSecurityPolicy
@@ -110,9 +111,9 @@ class Test(unittest.TestCase):
         self.assertTrue(queryInteraction() is None)
 
     def test_restoreInteraction_after_neither(self):
+        from zope.security._definitions import thread_local
         from zope.security.management import queryInteraction
         from zope.security.management import restoreInteraction
-        from zope.security._definitions import thread_local
         try:
             del thread_local.interaction
         except AttributeError:
@@ -125,22 +126,22 @@ class Test(unittest.TestCase):
         self.assertTrue(queryInteraction() is None)
 
     def test_checkPermission_w_no_interaction(self):
-        from zope.security.management import checkPermission
         from zope.security.interfaces import NoInteraction
+        from zope.security.management import checkPermission
         permission = 'zope.Test'
         obj = object()
         self.assertRaises(NoInteraction, checkPermission, permission, obj)
 
     def test_checkPermission_w_interaction(self):
         from zope.security.management import checkPermission
-        from zope.security.management import setSecurityPolicy
-        from zope.security.management import queryInteraction
         from zope.security.management import newInteraction
+        from zope.security.management import queryInteraction
+        from zope.security.management import setSecurityPolicy
 
         permission = 'zope.Test'
         obj = object()
 
-        class PolicyStub(object):
+        class PolicyStub:
             def checkPermission(s, p, o,):
                 self.assertTrue(p is permission)
                 self.assertTrue(o is obj)
@@ -155,12 +156,12 @@ class Test(unittest.TestCase):
     def test_checkPermission_forbidden_policy(self):
         from zope.security import checkPermission
         from zope.security.checker import CheckerPublic
-        from zope.security.management import setSecurityPolicy
         from zope.security.management import newInteraction
+        from zope.security.management import setSecurityPolicy
 
         obj = object()
 
-        class ForbiddenPolicyStub(object):
+        class ForbiddenPolicyStub:
             def checkPermission(s, p, o):
                 return False
 
@@ -172,18 +173,19 @@ class Test(unittest.TestCase):
 
     def test_system_user(self):
         from zope.interface.verify import verifyObject
+
         from zope.security.interfaces import IPrincipal
         from zope.security.interfaces import ISystemPrincipal
         from zope.security.management import system_user
 
         self.assertEqual(system_user.id,
-                         u'zope.security.management.system_user')
+                         'zope.security.management.system_user')
 
-        self.assertEqual(system_user.title, u'System')
+        self.assertEqual(system_user.title, 'System')
 
         for name in 'id', 'title', 'description':
             self.assertIsInstance(getattr(system_user, name),
-                                  type(u''))
+                                  str)
 
         verifyObject(IPrincipal, system_user)
         verifyObject(ISystemPrincipal, system_user)
